.. _api_fileio_filebase:

IO Base Classes (:mod:`pydicom.filebase`)
=========================================

.. currentmodule:: pydicom.filebase

Basic I/O support classes.

.. autosummary::
   :toctree: generated/

   DicomBytesIO
   DicomFile
   DicomFileLike
   DicomIO
